Module backbone

Module backbone 

Backbone (spanning forest) maintenance via union-find.

The Backbone keeps a set of always-present edges that guarantee global connectivity in the sparsifier. Non-backbone edges can be freely sampled and dropped; backbone edges are never removed unless the corresponding edge is deleted from the full graph.

Structs

Backbone
A spanning-forest backbone that maintains connectivity guarantees.