pub struct Backbone { /* private fields */ }Expand description
A spanning-forest backbone that maintains connectivity guarantees.
When an edge is inserted, it is added to the backbone forest if and only if it connects two previously disconnected components. When a backbone edge is deleted, the backbone attempts to find a replacement edge from the set of known non-backbone edges to restore connectivity.
Implementations