Trait definitions for the sparsifier framework.
These traits allow pluggable strategies for backbone maintenance, importance scoring, and the sparsifier itself.
Traits
- Backbone
Strategy - Strategy for maintaining a backbone (spanning forest) that ensures global connectivity in the sparsifier.
- Importance
Scorer - Strategy for scoring the importance of edges.
- Sparsifier
- A dynamic spectral sparsifier that maintains a compressed shadow graph
preserving the Laplacian energy of the original within
(1 +/- epsilon).